@@ -27,6 +27,14 @@ class PitchShift:
             # and the effect chain includes eg `pitch`
             if torch.isnan(y).any() or torch.isinf(y).any():
                 return audio.clone()
+
+            if y.shape[1] != audio.shape[1]:
+                if y.shape[1] > audio.shape[1]:
+                    y = y[:, audio.shape[1]]
+                else:
+                    y0 = torch.zeros(1, audio.shape[1])
+                    y0[:, :y.shape[1]] = y
+                    y = y0
             return y
 
         return audio
